# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RecipientFederationPolicyArgs', 'RecipientFederationPolicy']

@pulumi.input_type
class RecipientFederationPolicyArgs:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input['RecipientFederationPolicyOidcPolicyArgs']] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RecipientFederationPolicy resource.
        :param pulumi.Input[_builtins.str] comment: Description of the policy. This is a user-provided description
        :param pulumi.Input[_builtins.str] name: Name of the federation policy. A recipient can have multiple policies with different names.
               The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        :param pulumi.Input['RecipientFederationPolicyOidcPolicyArgs'] oidc_policy: Specifies the policy to use for validating OIDC claims in the federated tokens
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oidc_policy is not None:
            pulumi.set(__self__, "oidc_policy", oidc_policy)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the policy. This is a user-provided description
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the federation policy. A recipient can have multiple policies with different names.
        The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> Optional[pulumi.Input['RecipientFederationPolicyOidcPolicyArgs']]:
        """
        Specifies the policy to use for validating OIDC claims in the federated tokens
        """
        return pulumi.get(self, "oidc_policy")

    @oidc_policy.setter
    def oidc_policy(self, value: Optional[pulumi.Input['RecipientFederationPolicyOidcPolicyArgs']]):
        pulumi.set(self, "oidc_policy", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.input_type
class _RecipientFederationPolicyState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input['RecipientFederationPolicyOidcPolicyArgs']] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RecipientFederationPolicy resources.
        :param pulumi.Input[_builtins.str] comment: Description of the policy. This is a user-provided description
        :param pulumi.Input[_builtins.str] create_time: (string) - System-generated timestamp indicating when the policy was created
        :param pulumi.Input[_builtins.str] name: Name of the federation policy. A recipient can have multiple policies with different names.
               The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        :param pulumi.Input['RecipientFederationPolicyOidcPolicyArgs'] oidc_policy: Specifies the policy to use for validating OIDC claims in the federated tokens
        :param pulumi.Input[_builtins.str] update_time: (string) - System-generated timestamp indicating when the policy was last updated
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oidc_policy is not None:
            pulumi.set(__self__, "oidc_policy", oidc_policy)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the policy. This is a user-provided description
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - System-generated timestamp indicating when the policy was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the federation policy. A recipient can have multiple policies with different names.
        The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> Optional[pulumi.Input['RecipientFederationPolicyOidcPolicyArgs']]:
        """
        Specifies the policy to use for validating OIDC claims in the federated tokens
        """
        return pulumi.get(self, "oidc_policy")

    @oidc_policy.setter
    def oidc_policy(self, value: Optional[pulumi.Input['RecipientFederationPolicyOidcPolicyArgs']]):
        pulumi.set(self, "oidc_policy", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - System-generated timestamp indicating when the policy was last updated
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("databricks:index/recipientFederationPolicy:RecipientFederationPolicy")
class RecipientFederationPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input[Union['RecipientFederationPolicyOidcPolicyArgs', 'RecipientFederationPolicyOidcPolicyArgsDict']]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_recipient_federation_policy.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/recipientFederationPolicy:RecipientFederationPolicy databricks_recipient_federation_policy "name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: Description of the policy. This is a user-provided description
        :param pulumi.Input[_builtins.str] name: Name of the federation policy. A recipient can have multiple policies with different names.
               The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        :param pulumi.Input[Union['RecipientFederationPolicyOidcPolicyArgs', 'RecipientFederationPolicyOidcPolicyArgsDict']] oidc_policy: Specifies the policy to use for validating OIDC claims in the federated tokens
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RecipientFederationPolicyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_recipient_federation_policy.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/recipientFederationPolicy:RecipientFederationPolicy databricks_recipient_federation_policy "name"
        ```

        :param str resource_name: The name of the resource.
        :param RecipientFederationPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RecipientFederationPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input[Union['RecipientFederationPolicyOidcPolicyArgs', 'RecipientFederationPolicyOidcPolicyArgsDict']]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RecipientFederationPolicyArgs.__new__(RecipientFederationPolicyArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["name"] = name
            __props__.__dict__["oidc_policy"] = oidc_policy
            __props__.__dict__["workspace_id"] = workspace_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["update_time"] = None
        super(RecipientFederationPolicy, __self__).__init__(
            'databricks:index/recipientFederationPolicy:RecipientFederationPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            oidc_policy: Optional[pulumi.Input[Union['RecipientFederationPolicyOidcPolicyArgs', 'RecipientFederationPolicyOidcPolicyArgsDict']]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None,
            workspace_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'RecipientFederationPolicy':
        """
        Get an existing RecipientFederationPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: Description of the policy. This is a user-provided description
        :param pulumi.Input[_builtins.str] create_time: (string) - System-generated timestamp indicating when the policy was created
        :param pulumi.Input[_builtins.str] name: Name of the federation policy. A recipient can have multiple policies with different names.
               The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        :param pulumi.Input[Union['RecipientFederationPolicyOidcPolicyArgs', 'RecipientFederationPolicyOidcPolicyArgsDict']] oidc_policy: Specifies the policy to use for validating OIDC claims in the federated tokens
        :param pulumi.Input[_builtins.str] update_time: (string) - System-generated timestamp indicating when the policy was last updated
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RecipientFederationPolicyState.__new__(_RecipientFederationPolicyState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["name"] = name
        __props__.__dict__["oidc_policy"] = oidc_policy
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["workspace_id"] = workspace_id
        return RecipientFederationPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the policy. This is a user-provided description
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - System-generated timestamp indicating when the policy was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the federation policy. A recipient can have multiple policies with different names.
        The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> pulumi.Output[Optional['outputs.RecipientFederationPolicyOidcPolicy']]:
        """
        Specifies the policy to use for validating OIDC claims in the federated tokens
        """
        return pulumi.get(self, "oidc_policy")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - System-generated timestamp indicating when the policy was last updated
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetCleanRoomAssetsResult',
    'AwaitableGetCleanRoomAssetsResult',
    'get_clean_room_assets',
    'get_clean_room_assets_output',
]

@pulumi.output_type
class GetCleanRoomAssetsResult:
    """
    A collection of values returned by getCleanRoomAssets.
    """
    def __init__(__self__, assets=None, clean_room_name=None, id=None, workspace_id=None):
        if assets and not isinstance(assets, list):
            raise TypeError("Expected argument 'assets' to be a list")
        pulumi.set(__self__, "assets", assets)
        if clean_room_name and not isinstance(clean_room_name, str):
            raise TypeError("Expected argument 'clean_room_name' to be a str")
        pulumi.set(__self__, "clean_room_name", clean_room_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def assets(self) -> Sequence['outputs.GetCleanRoomAssetsAssetResult']:
        return pulumi.get(self, "assets")

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> _builtins.str:
        """
        (string) - The name of the clean room this asset belongs to.
        This field is required for create operations and populated by the server for responses
        """
        return pulumi.get(self, "clean_room_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "workspace_id")


class AwaitableGetCleanRoomAssetsResult(GetCleanRoomAssetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCleanRoomAssetsResult(
            assets=self.assets,
            clean_room_name=self.clean_room_name,
            id=self.id,
            workspace_id=self.workspace_id)


def get_clean_room_assets(clean_room_name: Optional[_builtins.str] = None,
                          workspace_id: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCleanRoomAssetsResult:
    """
    This data source can be used to fetch the list of clean room assets.

    ## Example Usage

    # Example: Clean Room Assets Datasource

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.index.CleanRoomsAsset("all")
    ```


    :param _builtins.str clean_room_name: Name of the clean room
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['cleanRoomName'] = clean_room_name
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getCleanRoomAssets:getCleanRoomAssets', __args__, opts=opts, typ=GetCleanRoomAssetsResult).value

    return AwaitableGetCleanRoomAssetsResult(
        assets=pulumi.get(__ret__, 'assets'),
        clean_room_name=pulumi.get(__ret__, 'clean_room_name'),
        id=pulumi.get(__ret__, 'id'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_clean_room_assets_output(clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                                 workspace_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCleanRoomAssetsResult]:
    """
    This data source can be used to fetch the list of clean room assets.

    ## Example Usage

    # Example: Clean Room Assets Datasource

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.index.CleanRoomsAsset("all")
    ```


    :param _builtins.str clean_room_name: Name of the clean room
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['cleanRoomName'] = clean_room_name
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getCleanRoomAssets:getCleanRoomAssets', __args__, opts=opts, typ=GetCleanRoomAssetsResult)
    return __ret__.apply(lambda __response__: GetCleanRoomAssetsResult(
        assets=pulumi.get(__response__, 'assets'),
        clean_room_name=pulumi.get(__response__, 'clean_room_name'),
        id=pulumi.get(__response__, 'id'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCleanRoomAutoApprovalRuleResult',
    'AwaitableGetCleanRoomAutoApprovalRuleResult',
    'get_clean_room_auto_approval_rule',
    'get_clean_room_auto_approval_rule_output',
]

@pulumi.output_type
class GetCleanRoomAutoApprovalRuleResult:
    """
    A collection of values returned by getCleanRoomAutoApprovalRule.
    """
    def __init__(__self__, author_collaborator_alias=None, author_scope=None, clean_room_name=None, created_at=None, id=None, rule_id=None, rule_owner_collaborator_alias=None, runner_collaborator_alias=None, workspace_id=None):
        if author_collaborator_alias and not isinstance(author_collaborator_alias, str):
            raise TypeError("Expected argument 'author_collaborator_alias' to be a str")
        pulumi.set(__self__, "author_collaborator_alias", author_collaborator_alias)
        if author_scope and not isinstance(author_scope, str):
            raise TypeError("Expected argument 'author_scope' to be a str")
        pulumi.set(__self__, "author_scope", author_scope)
        if clean_room_name and not isinstance(clean_room_name, str):
            raise TypeError("Expected argument 'clean_room_name' to be a str")
        pulumi.set(__self__, "clean_room_name", clean_room_name)
        if created_at and not isinstance(created_at, int):
            raise TypeError("Expected argument 'created_at' to be a int")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if rule_id and not isinstance(rule_id, str):
            raise TypeError("Expected argument 'rule_id' to be a str")
        pulumi.set(__self__, "rule_id", rule_id)
        if rule_owner_collaborator_alias and not isinstance(rule_owner_collaborator_alias, str):
            raise TypeError("Expected argument 'rule_owner_collaborator_alias' to be a str")
        pulumi.set(__self__, "rule_owner_collaborator_alias", rule_owner_collaborator_alias)
        if runner_collaborator_alias and not isinstance(runner_collaborator_alias, str):
            raise TypeError("Expected argument 'runner_collaborator_alias' to be a str")
        pulumi.set(__self__, "runner_collaborator_alias", runner_collaborator_alias)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="authorCollaboratorAlias")
    def author_collaborator_alias(self) -> Optional[_builtins.str]:
        """
        (string) - Collaborator alias of the author covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set
        """
        return pulumi.get(self, "author_collaborator_alias")

    @_builtins.property
    @pulumi.getter(name="authorScope")
    def author_scope(self) -> Optional[_builtins.str]:
        """
        (string) - Scope of authors covered by the rule.
        Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
        """
        return pulumi.get(self, "author_scope")

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> Optional[_builtins.str]:
        """
        (string) - The name of the clean room this auto-approval rule belongs to
        """
        return pulumi.get(self, "clean_room_name")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.int:
        """
        (integer) - Timestamp of when the rule was created, in epoch milliseconds
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.str:
        """
        (string) - A generated UUID identifying the rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="ruleOwnerCollaboratorAlias")
    def rule_owner_collaborator_alias(self) -> _builtins.str:
        """
        (string) - The owner of the rule to whom the rule applies
        """
        return pulumi.get(self, "rule_owner_collaborator_alias")

    @_builtins.property
    @pulumi.getter(name="runnerCollaboratorAlias")
    def runner_collaborator_alias(self) -> Optional[_builtins.str]:
        """
        (string) - Collaborator alias of the runner covered by the rule
        """
        return pulumi.get(self, "runner_collaborator_alias")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "workspace_id")


class AwaitableGetCleanRoomAutoApprovalRuleResult(GetCleanRoomAutoApprovalRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCleanRoomAutoApprovalRuleResult(
            author_collaborator_alias=self.author_collaborator_alias,
            author_scope=self.author_scope,
            clean_room_name=self.clean_room_name,
            created_at=self.created_at,
            id=self.id,
            rule_id=self.rule_id,
            rule_owner_collaborator_alias=self.rule_owner_collaborator_alias,
            runner_collaborator_alias=self.runner_collaborator_alias,
            workspace_id=self.workspace_id)


def get_clean_room_auto_approval_rule(author_collaborator_alias: Optional[_builtins.str] = None,
                                      author_scope: Optional[_builtins.str] = None,
                                      clean_room_name: Optional[_builtins.str] = None,
                                      runner_collaborator_alias: Optional[_builtins.str] = None,
                                      workspace_id: Optional[_builtins.str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCleanRoomAutoApprovalRuleResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str author_collaborator_alias: (string) - Collaborator alias of the author covered by the rule.
           Only one of `author_collaborator_alias` and `author_scope` can be set
    :param _builtins.str author_scope: (string) - Scope of authors covered by the rule.
           Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
    :param _builtins.str clean_room_name: (string) - The name of the clean room this auto-approval rule belongs to
    :param _builtins.str runner_collaborator_alias: (string) - Collaborator alias of the runner covered by the rule
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['authorCollaboratorAlias'] = author_collaborator_alias
    __args__['authorScope'] = author_scope
    __args__['cleanRoomName'] = clean_room_name
    __args__['runnerCollaboratorAlias'] = runner_collaborator_alias
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getCleanRoomAutoApprovalRule:getCleanRoomAutoApprovalRule', __args__, opts=opts, typ=GetCleanRoomAutoApprovalRuleResult).value

    return AwaitableGetCleanRoomAutoApprovalRuleResult(
        author_collaborator_alias=pulumi.get(__ret__, 'author_collaborator_alias'),
        author_scope=pulumi.get(__ret__, 'author_scope'),
        clean_room_name=pulumi.get(__ret__, 'clean_room_name'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        rule_id=pulumi.get(__ret__, 'rule_id'),
        rule_owner_collaborator_alias=pulumi.get(__ret__, 'rule_owner_collaborator_alias'),
        runner_collaborator_alias=pulumi.get(__ret__, 'runner_collaborator_alias'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_clean_room_auto_approval_rule_output(author_collaborator_alias: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             author_scope: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             clean_room_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             runner_collaborator_alias: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             workspace_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCleanRoomAutoApprovalRuleResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str author_collaborator_alias: (string) - Collaborator alias of the author covered by the rule.
           Only one of `author_collaborator_alias` and `author_scope` can be set
    :param _builtins.str author_scope: (string) - Scope of authors covered by the rule.
           Only one of `author_collaborator_alias` and `author_scope` can be set. Possible values are: `ANY_AUTHOR`
    :param _builtins.str clean_room_name: (string) - The name of the clean room this auto-approval rule belongs to
    :param _builtins.str runner_collaborator_alias: (string) - Collaborator alias of the runner covered by the rule
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['authorCollaboratorAlias'] = author_collaborator_alias
    __args__['authorScope'] = author_scope
    __args__['cleanRoomName'] = clean_room_name
    __args__['runnerCollaboratorAlias'] = runner_collaborator_alias
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getCleanRoomAutoApprovalRule:getCleanRoomAutoApprovalRule', __args__, opts=opts, typ=GetCleanRoomAutoApprovalRuleResult)
    return __ret__.apply(lambda __response__: GetCleanRoomAutoApprovalRuleResult(
        author_collaborator_alias=pulumi.get(__response__, 'author_collaborator_alias'),
        author_scope=pulumi.get(__response__, 'author_scope'),
        clean_room_name=pulumi.get(__response__, 'clean_room_name'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        rule_id=pulumi.get(__response__, 'rule_id'),
        rule_owner_collaborator_alias=pulumi.get(__response__, 'rule_owner_collaborator_alias'),
        runner_collaborator_alias=pulumi.get(__response__, 'runner_collaborator_alias'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCleanRoomsCleanRoomResult',
    'AwaitableGetCleanRoomsCleanRoomResult',
    'get_clean_rooms_clean_room',
    'get_clean_rooms_clean_room_output',
]

@pulumi.output_type
class GetCleanRoomsCleanRoomResult:
    """
    A collection of values returned by getCleanRoomsCleanRoom.
    """
    def __init__(__self__, access_restricted=None, comment=None, created_at=None, id=None, local_collaborator_alias=None, name=None, output_catalog=None, owner=None, remote_detailed_info=None, status=None, updated_at=None, workspace_id=None):
        if access_restricted and not isinstance(access_restricted, str):
            raise TypeError("Expected argument 'access_restricted' to be a str")
        pulumi.set(__self__, "access_restricted", access_restricted)
        if comment and not isinstance(comment, str):
            raise TypeError("Expected argument 'comment' to be a str")
        pulumi.set(__self__, "comment", comment)
        if created_at and not isinstance(created_at, int):
            raise TypeError("Expected argument 'created_at' to be a int")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if local_collaborator_alias and not isinstance(local_collaborator_alias, str):
            raise TypeError("Expected argument 'local_collaborator_alias' to be a str")
        pulumi.set(__self__, "local_collaborator_alias", local_collaborator_alias)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if output_catalog and not isinstance(output_catalog, dict):
            raise TypeError("Expected argument 'output_catalog' to be a dict")
        pulumi.set(__self__, "output_catalog", output_catalog)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if remote_detailed_info and not isinstance(remote_detailed_info, dict):
            raise TypeError("Expected argument 'remote_detailed_info' to be a dict")
        pulumi.set(__self__, "remote_detailed_info", remote_detailed_info)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if updated_at and not isinstance(updated_at, int):
            raise TypeError("Expected argument 'updated_at' to be a int")
        pulumi.set(__self__, "updated_at", updated_at)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="accessRestricted")
    def access_restricted(self) -> _builtins.str:
        """
        (string) - Whether clean room access is restricted due to [CSP](https://docs.databricks.com/en/security/privacy/security-profile.html). Possible values are: `CSP_MISMATCH`, `NO_RESTRICTION`
        """
        return pulumi.get(self, "access_restricted")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[_builtins.str]:
        """
        (string)
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.int:
        """
        (integer) - When the clean room was created, in epoch milliseconds
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="localCollaboratorAlias")
    def local_collaborator_alias(self) -> _builtins.str:
        """
        (string) - The alias of the collaborator tied to the local clean room
        """
        return pulumi.get(self, "local_collaborator_alias")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        (string) - The name of the clean room.
        It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="outputCatalog")
    def output_catalog(self) -> 'outputs.GetCleanRoomsCleanRoomOutputCatalogResult':
        """
        (CleanRoomOutputCatalog) - Output catalog of the clean room. It is an output only field. Output catalog is manipulated
        using the separate CreateCleanRoomOutputCatalog API
        """
        return pulumi.get(self, "output_catalog")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[_builtins.str]:
        """
        (string) - This is the Databricks username of the owner of the local clean room securable for permission management
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="remoteDetailedInfo")
    def remote_detailed_info(self) -> Optional['outputs.GetCleanRoomsCleanRoomRemoteDetailedInfoResult']:
        """
        (CleanRoomRemoteDetail) - Central clean room details. During creation, users need to specify
        cloud_vendor, region, and collaborators.global_metastore_id.
        This field will not be filled in the ListCleanRooms call
        """
        return pulumi.get(self, "remote_detailed_info")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (string) - . Possible values are: `CREATED`, `NOT_CREATED`, `NOT_ELIGIBLE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.int:
        """
        (integer) - When the clean room was last updated, in epoch milliseconds
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "workspace_id")


class AwaitableGetCleanRoomsCleanRoomResult(GetCleanRoomsCleanRoomResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCleanRoomsCleanRoomResult(
            access_restricted=self.access_restricted,
            comment=self.comment,
            created_at=self.created_at,
            id=self.id,
            local_collaborator_alias=self.local_collaborator_alias,
            name=self.name,
            output_catalog=self.output_catalog,
            owner=self.owner,
            remote_detailed_info=self.remote_detailed_info,
            status=self.status,
            updated_at=self.updated_at,
            workspace_id=self.workspace_id)


def get_clean_rooms_clean_room(comment: Optional[_builtins.str] = None,
                               name: Optional[_builtins.str] = None,
                               owner: Optional[_builtins.str] = None,
                               remote_detailed_info: Optional[Union['GetCleanRoomsCleanRoomRemoteDetailedInfoArgs', 'GetCleanRoomsCleanRoomRemoteDetailedInfoArgsDict']] = None,
                               workspace_id: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCleanRoomsCleanRoomResult:
    """
    This data source can be used to get a single clean room.

    ## Example Usage

    # Example: Datasource (Singular) Artifact

    ```python
    import pulumi
    import pulumi_databricks as databricks

    example = databricks.get_clean_rooms_clean_room(name="example-clean-room")
    ```


    :param _builtins.str comment: (string)
    :param _builtins.str name: The name of the clean room.
           It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
    :param _builtins.str owner: (string) - This is the Databricks username of the owner of the local clean room securable for permission management
    :param Union['GetCleanRoomsCleanRoomRemoteDetailedInfoArgs', 'GetCleanRoomsCleanRoomRemoteDetailedInfoArgsDict'] remote_detailed_info: (CleanRoomRemoteDetail) - Central clean room details. During creation, users need to specify
           cloud_vendor, region, and collaborators.global_metastore_id.
           This field will not be filled in the ListCleanRooms call
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['comment'] = comment
    __args__['name'] = name
    __args__['owner'] = owner
    __args__['remoteDetailedInfo'] = remote_detailed_info
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getCleanRoomsCleanRoom:getCleanRoomsCleanRoom', __args__, opts=opts, typ=GetCleanRoomsCleanRoomResult).value

    return AwaitableGetCleanRoomsCleanRoomResult(
        access_restricted=pulumi.get(__ret__, 'access_restricted'),
        comment=pulumi.get(__ret__, 'comment'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        local_collaborator_alias=pulumi.get(__ret__, 'local_collaborator_alias'),
        name=pulumi.get(__ret__, 'name'),
        output_catalog=pulumi.get(__ret__, 'output_catalog'),
        owner=pulumi.get(__ret__, 'owner'),
        remote_detailed_info=pulumi.get(__ret__, 'remote_detailed_info'),
        status=pulumi.get(__ret__, 'status'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_clean_rooms_clean_room_output(comment: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      owner: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      remote_detailed_info: Optional[pulumi.Input[Optional[Union['GetCleanRoomsCleanRoomRemoteDetailedInfoArgs', 'GetCleanRoomsCleanRoomRemoteDetailedInfoArgsDict']]]] = None,
                                      workspace_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCleanRoomsCleanRoomResult]:
    """
    This data source can be used to get a single clean room.

    ## Example Usage

    # Example: Datasource (Singular) Artifact

    ```python
    import pulumi
    import pulumi_databricks as databricks

    example = databricks.get_clean_rooms_clean_room(name="example-clean-room")
    ```


    :param _builtins.str comment: (string)
    :param _builtins.str name: The name of the clean room.
           It should follow [UC securable naming requirements](https://docs.databricks.com/en/data-governance/unity-catalog/index.html#securable-object-naming-requirements)
    :param _builtins.str owner: (string) - This is the Databricks username of the owner of the local clean room securable for permission management
    :param Union['GetCleanRoomsCleanRoomRemoteDetailedInfoArgs', 'GetCleanRoomsCleanRoomRemoteDetailedInfoArgsDict'] remote_detailed_info: (CleanRoomRemoteDetail) - Central clean room details. During creation, users need to specify
           cloud_vendor, region, and collaborators.global_metastore_id.
           This field will not be filled in the ListCleanRooms call
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['comment'] = comment
    __args__['name'] = name
    __args__['owner'] = owner
    __args__['remoteDetailedInfo'] = remote_detailed_info
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getCleanRoomsCleanRoom:getCleanRoomsCleanRoom', __args__, opts=opts, typ=GetCleanRoomsCleanRoomResult)
    return __ret__.apply(lambda __response__: GetCleanRoomsCleanRoomResult(
        access_restricted=pulumi.get(__response__, 'access_restricted'),
        comment=pulumi.get(__response__, 'comment'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        local_collaborator_alias=pulumi.get(__response__, 'local_collaborator_alias'),
        name=pulumi.get(__response__, 'name'),
        output_catalog=pulumi.get(__response__, 'output_catalog'),
        owner=pulumi.get(__response__, 'owner'),
        remote_detailed_info=pulumi.get(__response__, 'remote_detailed_info'),
        status=pulumi.get(__response__, 'status'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRecipientFederationPolicyResult',
    'AwaitableGetRecipientFederationPolicyResult',
    'get_recipient_federation_policy',
    'get_recipient_federation_policy_output',
]

@pulumi.output_type
class GetRecipientFederationPolicyResult:
    """
    A collection of values returned by getRecipientFederationPolicy.
    """
    def __init__(__self__, comment=None, create_time=None, id=None, name=None, oidc_policy=None, update_time=None, workspace_id=None):
        if comment and not isinstance(comment, str):
            raise TypeError("Expected argument 'comment' to be a str")
        pulumi.set(__self__, "comment", comment)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if oidc_policy and not isinstance(oidc_policy, dict):
            raise TypeError("Expected argument 'oidc_policy' to be a dict")
        pulumi.set(__self__, "oidc_policy", oidc_policy)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[_builtins.str]:
        """
        (string) - Description of the policy. This is a user-provided description
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> _builtins.str:
        """
        (string) - System-generated timestamp indicating when the policy was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (string) - Unique, immutable system-generated identifier for the federation policy
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        (string) - Name of the federation policy. A recipient can have multiple policies with different names.
        The name must contain only lowercase alphanumeric characters, numbers, and hyphens
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> Optional['outputs.GetRecipientFederationPolicyOidcPolicyResult']:
        """
        (OidcFederationPolicy) - Specifies the policy to use for validating OIDC claims in the federated tokens
        """
        return pulumi.get(self, "oidc_policy")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> _builtins.str:
        """
        (string) - System-generated timestamp indicating when the policy was last updated
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "workspace_id")


class AwaitableGetRecipientFederationPolicyResult(GetRecipientFederationPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRecipientFederationPolicyResult(
            comment=self.comment,
            create_time=self.create_time,
            id=self.id,
            name=self.name,
            oidc_policy=self.oidc_policy,
            update_time=self.update_time,
            workspace_id=self.workspace_id)


def get_recipient_federation_policy(comment: Optional[_builtins.str] = None,
                                    name: Optional[_builtins.str] = None,
                                    oidc_policy: Optional[Union['GetRecipientFederationPolicyOidcPolicyArgs', 'GetRecipientFederationPolicyOidcPolicyArgsDict']] = None,
                                    workspace_id: Optional[_builtins.str] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRecipientFederationPolicyResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str comment: (string) - Description of the policy. This is a user-provided description
    :param _builtins.str name: Name of the federation policy. A recipient can have multiple policies with different names.
           The name must contain only lowercase alphanumeric characters, numbers, and hyphens
    :param Union['GetRecipientFederationPolicyOidcPolicyArgs', 'GetRecipientFederationPolicyOidcPolicyArgsDict'] oidc_policy: (OidcFederationPolicy) - Specifies the policy to use for validating OIDC claims in the federated tokens
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['comment'] = comment
    __args__['name'] = name
    __args__['oidcPolicy'] = oidc_policy
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getRecipientFederationPolicy:getRecipientFederationPolicy', __args__, opts=opts, typ=GetRecipientFederationPolicyResult).value

    return AwaitableGetRecipientFederationPolicyResult(
        comment=pulumi.get(__ret__, 'comment'),
        create_time=pulumi.get(__ret__, 'create_time'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        oidc_policy=pulumi.get(__ret__, 'oidc_policy'),
        update_time=pulumi.get(__ret__, 'update_time'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_recipient_federation_policy_output(comment: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                           name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                           oidc_policy: Optional[pulumi.Input[Optional[Union['GetRecipientFederationPolicyOidcPolicyArgs', 'GetRecipientFederationPolicyOidcPolicyArgsDict']]]] = None,
                                           workspace_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRecipientFederationPolicyResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str comment: (string) - Description of the policy. This is a user-provided description
    :param _builtins.str name: Name of the federation policy. A recipient can have multiple policies with different names.
           The name must contain only lowercase alphanumeric characters, numbers, and hyphens
    :param Union['GetRecipientFederationPolicyOidcPolicyArgs', 'GetRecipientFederationPolicyOidcPolicyArgsDict'] oidc_policy: (OidcFederationPolicy) - Specifies the policy to use for validating OIDC claims in the federated tokens
    :param _builtins.str workspace_id: Workspace ID of the resource
    """
    __args__ = dict()
    __args__['comment'] = comment
    __args__['name'] = name
    __args__['oidcPolicy'] = oidc_policy
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getRecipientFederationPolicy:getRecipientFederationPolicy', __args__, opts=opts, typ=GetRecipientFederationPolicyResult)
    return __ret__.apply(lambda __response__: GetRecipientFederationPolicyResult(
        comment=pulumi.get(__response__, 'comment'),
        create_time=pulumi.get(__response__, 'create_time'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        oidc_policy=pulumi.get(__response__, 'oidc_policy'),
        update_time=pulumi.get(__response__, 'update_time'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAppResult',
    'AwaitableGetAppResult',
    'get_app',
    'get_app_output',
]

@pulumi.output_type
class GetAppResult:
    """
    A collection of values returned by getApp.
    """
    def __init__(__self__, app=None, id=None, name=None):
        if app and not isinstance(app, dict):
            raise TypeError("Expected argument 'app' to be a dict")
        pulumi.set(__self__, "app", app)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def app(self) -> 'outputs.GetAppAppResult':
        """
        attribute
        """
        return pulumi.get(self, "app")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the serving endpoint to grant permission on.
        """
        return pulumi.get(self, "name")


class AwaitableGetAppResult(GetAppResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppResult(
            app=self.app,
            id=self.id,
            name=self.name)


def get_app(name: Optional[_builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppResult:
    """
    > This data source can only be used with a workspace-level provider!

    [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html) run directly on a customer’s Databricks instance, integrate with their data, use and extend Databricks services, and enable users to interact through single sign-on. This resource creates the application but does not handle app deployment, which should be handled separately as part of your CI/CD pipeline.

    This data source allows you to fetch information about a Databricks App.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_app(name="my-custom-app")
    ```

    ## Related Resources

    The following resources are used in the same context:

    * App to manage [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html).
    * SqlEndpoint to manage Databricks SQL [Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
    * ModelServing to serve this model on a Databricks serving endpoint.
    * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code.


    :param _builtins.str name: The name of the app.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getApp:getApp', __args__, opts=opts, typ=GetAppResult).value

    return AwaitableGetAppResult(
        app=pulumi.get(__ret__, 'app'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_app_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAppResult]:
    """
    > This data source can only be used with a workspace-level provider!

    [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html) run directly on a customer’s Databricks instance, integrate with their data, use and extend Databricks services, and enable users to interact through single sign-on. This resource creates the application but does not handle app deployment, which should be handled separately as part of your CI/CD pipeline.

    This data source allows you to fetch information about a Databricks App.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_app(name="my-custom-app")
    ```

    ## Related Resources

    The following resources are used in the same context:

    * App to manage [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html).
    * SqlEndpoint to manage Databricks SQL [Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
    * ModelServing to serve this model on a Databricks serving endpoint.
    * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code.


    :param _builtins.str name: The name of the app.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getApp:getApp', __args__, opts=opts, typ=GetAppResult)
    return __ret__.apply(lambda __response__: GetAppResult(
        app=pulumi.get(__response__, 'app'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CleanRoomAssetArgs', 'CleanRoomAsset']

@pulumi.input_type
class CleanRoomAssetArgs:
    def __init__(__self__, *,
                 asset_type: pulumi.Input[_builtins.str],
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 foreign_table: Optional[pulumi.Input['CleanRoomAssetForeignTableArgs']] = None,
                 foreign_table_local_details: Optional[pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notebook: Optional[pulumi.Input['CleanRoomAssetNotebookArgs']] = None,
                 table: Optional[pulumi.Input['CleanRoomAssetTableArgs']] = None,
                 table_local_details: Optional[pulumi.Input['CleanRoomAssetTableLocalDetailsArgs']] = None,
                 view: Optional[pulumi.Input['CleanRoomAssetViewArgs']] = None,
                 view_local_details: Optional[pulumi.Input['CleanRoomAssetViewLocalDetailsArgs']] = None,
                 volume_local_details: Optional[pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs']] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CleanRoomAsset resource.
        :param pulumi.Input[_builtins.str] asset_type: The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this asset belongs to.
               This field is required for create operations and populated by the server for responses
        :param pulumi.Input['CleanRoomAssetForeignTableArgs'] foreign_table: Foreign table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs'] foreign_table_local_details: Local details for a foreign that are only available to its owner.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input[_builtins.str] name: A fully qualified name that uniquely identifies the asset within the clean room.
               This is also the name displayed in the clean room UI.
               
               For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*
               
               For notebooks, the name is the notebook file name.
               For jar analyses, the name is the jar analysis name
        :param pulumi.Input['CleanRoomAssetNotebookArgs'] notebook: Notebook details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **NOTEBOOK_FILE**
        :param pulumi.Input['CleanRoomAssetTableArgs'] table: Table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input['CleanRoomAssetTableLocalDetailsArgs'] table_local_details: Local details for a table that are only available to its owner.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input['CleanRoomAssetViewArgs'] view: View details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input['CleanRoomAssetViewLocalDetailsArgs'] view_local_details: Local details for a view that are only available to its owner.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs'] volume_local_details: Local details for a volume that are only available to its owner.
               Present if and only if **asset_type** is **VOLUME**
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        pulumi.set(__self__, "asset_type", asset_type)
        if clean_room_name is not None:
            pulumi.set(__self__, "clean_room_name", clean_room_name)
        if foreign_table is not None:
            pulumi.set(__self__, "foreign_table", foreign_table)
        if foreign_table_local_details is not None:
            pulumi.set(__self__, "foreign_table_local_details", foreign_table_local_details)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notebook is not None:
            pulumi.set(__self__, "notebook", notebook)
        if table is not None:
            pulumi.set(__self__, "table", table)
        if table_local_details is not None:
            pulumi.set(__self__, "table_local_details", table_local_details)
        if view is not None:
            pulumi.set(__self__, "view", view)
        if view_local_details is not None:
            pulumi.set(__self__, "view_local_details", view_local_details)
        if volume_local_details is not None:
            pulumi.set(__self__, "volume_local_details", volume_local_details)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        """
        return pulumi.get(self, "asset_type")

    @asset_type.setter
    def asset_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "asset_type", value)

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the clean room this asset belongs to.
        This field is required for create operations and populated by the server for responses
        """
        return pulumi.get(self, "clean_room_name")

    @clean_room_name.setter
    def clean_room_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "clean_room_name", value)

    @_builtins.property
    @pulumi.getter(name="foreignTable")
    def foreign_table(self) -> Optional[pulumi.Input['CleanRoomAssetForeignTableArgs']]:
        """
        Foreign table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table")

    @foreign_table.setter
    def foreign_table(self, value: Optional[pulumi.Input['CleanRoomAssetForeignTableArgs']]):
        pulumi.set(self, "foreign_table", value)

    @_builtins.property
    @pulumi.getter(name="foreignTableLocalDetails")
    def foreign_table_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs']]:
        """
        Local details for a foreign that are only available to its owner.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table_local_details")

    @foreign_table_local_details.setter
    def foreign_table_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs']]):
        pulumi.set(self, "foreign_table_local_details", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A fully qualified name that uniquely identifies the asset within the clean room.
        This is also the name displayed in the clean room UI.

        For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*

        For notebooks, the name is the notebook file name.
        For jar analyses, the name is the jar analysis name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def notebook(self) -> Optional[pulumi.Input['CleanRoomAssetNotebookArgs']]:
        """
        Notebook details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **NOTEBOOK_FILE**
        """
        return pulumi.get(self, "notebook")

    @notebook.setter
    def notebook(self, value: Optional[pulumi.Input['CleanRoomAssetNotebookArgs']]):
        pulumi.set(self, "notebook", value)

    @_builtins.property
    @pulumi.getter
    def table(self) -> Optional[pulumi.Input['CleanRoomAssetTableArgs']]:
        """
        Table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table")

    @table.setter
    def table(self, value: Optional[pulumi.Input['CleanRoomAssetTableArgs']]):
        pulumi.set(self, "table", value)

    @_builtins.property
    @pulumi.getter(name="tableLocalDetails")
    def table_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetTableLocalDetailsArgs']]:
        """
        Local details for a table that are only available to its owner.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table_local_details")

    @table_local_details.setter
    def table_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetTableLocalDetailsArgs']]):
        pulumi.set(self, "table_local_details", value)

    @_builtins.property
    @pulumi.getter
    def view(self) -> Optional[pulumi.Input['CleanRoomAssetViewArgs']]:
        """
        View details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view")

    @view.setter
    def view(self, value: Optional[pulumi.Input['CleanRoomAssetViewArgs']]):
        pulumi.set(self, "view", value)

    @_builtins.property
    @pulumi.getter(name="viewLocalDetails")
    def view_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetViewLocalDetailsArgs']]:
        """
        Local details for a view that are only available to its owner.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view_local_details")

    @view_local_details.setter
    def view_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetViewLocalDetailsArgs']]):
        pulumi.set(self, "view_local_details", value)

    @_builtins.property
    @pulumi.getter(name="volumeLocalDetails")
    def volume_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs']]:
        """
        Local details for a volume that are only available to its owner.
        Present if and only if **asset_type** is **VOLUME**
        """
        return pulumi.get(self, "volume_local_details")

    @volume_local_details.setter
    def volume_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs']]):
        pulumi.set(self, "volume_local_details", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.input_type
class _CleanRoomAssetState:
    def __init__(__self__, *,
                 added_at: Optional[pulumi.Input[_builtins.int]] = None,
                 asset_type: Optional[pulumi.Input[_builtins.str]] = None,
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 foreign_table: Optional[pulumi.Input['CleanRoomAssetForeignTableArgs']] = None,
                 foreign_table_local_details: Optional[pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notebook: Optional[pulumi.Input['CleanRoomAssetNotebookArgs']] = None,
                 owner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 table: Optional[pulumi.Input['CleanRoomAssetTableArgs']] = None,
                 table_local_details: Optional[pulumi.Input['CleanRoomAssetTableLocalDetailsArgs']] = None,
                 view: Optional[pulumi.Input['CleanRoomAssetViewArgs']] = None,
                 view_local_details: Optional[pulumi.Input['CleanRoomAssetViewLocalDetailsArgs']] = None,
                 volume_local_details: Optional[pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs']] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CleanRoomAsset resources.
        :param pulumi.Input[_builtins.int] added_at: (integer) - When the asset is added to the clean room, in epoch milliseconds
        :param pulumi.Input[_builtins.str] asset_type: The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this asset belongs to.
               This field is required for create operations and populated by the server for responses
        :param pulumi.Input['CleanRoomAssetForeignTableArgs'] foreign_table: Foreign table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs'] foreign_table_local_details: Local details for a foreign that are only available to its owner.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input[_builtins.str] name: A fully qualified name that uniquely identifies the asset within the clean room.
               This is also the name displayed in the clean room UI.
               
               For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*
               
               For notebooks, the name is the notebook file name.
               For jar analyses, the name is the jar analysis name
        :param pulumi.Input['CleanRoomAssetNotebookArgs'] notebook: Notebook details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **NOTEBOOK_FILE**
        :param pulumi.Input[_builtins.str] owner_collaborator_alias: (string) - The alias of the collaborator who owns this asset
        :param pulumi.Input[_builtins.str] status: (string) - Status of the asset. Possible values are: `ACTIVE`, `PENDING`, `PERMISSION_DENIED`
        :param pulumi.Input['CleanRoomAssetTableArgs'] table: Table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input['CleanRoomAssetTableLocalDetailsArgs'] table_local_details: Local details for a table that are only available to its owner.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input['CleanRoomAssetViewArgs'] view: View details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input['CleanRoomAssetViewLocalDetailsArgs'] view_local_details: Local details for a view that are only available to its owner.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs'] volume_local_details: Local details for a volume that are only available to its owner.
               Present if and only if **asset_type** is **VOLUME**
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if added_at is not None:
            pulumi.set(__self__, "added_at", added_at)
        if asset_type is not None:
            pulumi.set(__self__, "asset_type", asset_type)
        if clean_room_name is not None:
            pulumi.set(__self__, "clean_room_name", clean_room_name)
        if foreign_table is not None:
            pulumi.set(__self__, "foreign_table", foreign_table)
        if foreign_table_local_details is not None:
            pulumi.set(__self__, "foreign_table_local_details", foreign_table_local_details)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notebook is not None:
            pulumi.set(__self__, "notebook", notebook)
        if owner_collaborator_alias is not None:
            pulumi.set(__self__, "owner_collaborator_alias", owner_collaborator_alias)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if table is not None:
            pulumi.set(__self__, "table", table)
        if table_local_details is not None:
            pulumi.set(__self__, "table_local_details", table_local_details)
        if view is not None:
            pulumi.set(__self__, "view", view)
        if view_local_details is not None:
            pulumi.set(__self__, "view_local_details", view_local_details)
        if volume_local_details is not None:
            pulumi.set(__self__, "volume_local_details", volume_local_details)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="addedAt")
    def added_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - When the asset is added to the clean room, in epoch milliseconds
        """
        return pulumi.get(self, "added_at")

    @added_at.setter
    def added_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "added_at", value)

    @_builtins.property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        """
        return pulumi.get(self, "asset_type")

    @asset_type.setter
    def asset_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "asset_type", value)

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the clean room this asset belongs to.
        This field is required for create operations and populated by the server for responses
        """
        return pulumi.get(self, "clean_room_name")

    @clean_room_name.setter
    def clean_room_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "clean_room_name", value)

    @_builtins.property
    @pulumi.getter(name="foreignTable")
    def foreign_table(self) -> Optional[pulumi.Input['CleanRoomAssetForeignTableArgs']]:
        """
        Foreign table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table")

    @foreign_table.setter
    def foreign_table(self, value: Optional[pulumi.Input['CleanRoomAssetForeignTableArgs']]):
        pulumi.set(self, "foreign_table", value)

    @_builtins.property
    @pulumi.getter(name="foreignTableLocalDetails")
    def foreign_table_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs']]:
        """
        Local details for a foreign that are only available to its owner.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table_local_details")

    @foreign_table_local_details.setter
    def foreign_table_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetForeignTableLocalDetailsArgs']]):
        pulumi.set(self, "foreign_table_local_details", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A fully qualified name that uniquely identifies the asset within the clean room.
        This is also the name displayed in the clean room UI.

        For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*

        For notebooks, the name is the notebook file name.
        For jar analyses, the name is the jar analysis name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def notebook(self) -> Optional[pulumi.Input['CleanRoomAssetNotebookArgs']]:
        """
        Notebook details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **NOTEBOOK_FILE**
        """
        return pulumi.get(self, "notebook")

    @notebook.setter
    def notebook(self, value: Optional[pulumi.Input['CleanRoomAssetNotebookArgs']]):
        pulumi.set(self, "notebook", value)

    @_builtins.property
    @pulumi.getter(name="ownerCollaboratorAlias")
    def owner_collaborator_alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The alias of the collaborator who owns this asset
        """
        return pulumi.get(self, "owner_collaborator_alias")

    @owner_collaborator_alias.setter
    def owner_collaborator_alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_collaborator_alias", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Status of the asset. Possible values are: `ACTIVE`, `PENDING`, `PERMISSION_DENIED`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def table(self) -> Optional[pulumi.Input['CleanRoomAssetTableArgs']]:
        """
        Table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table")

    @table.setter
    def table(self, value: Optional[pulumi.Input['CleanRoomAssetTableArgs']]):
        pulumi.set(self, "table", value)

    @_builtins.property
    @pulumi.getter(name="tableLocalDetails")
    def table_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetTableLocalDetailsArgs']]:
        """
        Local details for a table that are only available to its owner.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table_local_details")

    @table_local_details.setter
    def table_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetTableLocalDetailsArgs']]):
        pulumi.set(self, "table_local_details", value)

    @_builtins.property
    @pulumi.getter
    def view(self) -> Optional[pulumi.Input['CleanRoomAssetViewArgs']]:
        """
        View details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view")

    @view.setter
    def view(self, value: Optional[pulumi.Input['CleanRoomAssetViewArgs']]):
        pulumi.set(self, "view", value)

    @_builtins.property
    @pulumi.getter(name="viewLocalDetails")
    def view_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetViewLocalDetailsArgs']]:
        """
        Local details for a view that are only available to its owner.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view_local_details")

    @view_local_details.setter
    def view_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetViewLocalDetailsArgs']]):
        pulumi.set(self, "view_local_details", value)

    @_builtins.property
    @pulumi.getter(name="volumeLocalDetails")
    def volume_local_details(self) -> Optional[pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs']]:
        """
        Local details for a volume that are only available to its owner.
        Present if and only if **asset_type** is **VOLUME**
        """
        return pulumi.get(self, "volume_local_details")

    @volume_local_details.setter
    def volume_local_details(self, value: Optional[pulumi.Input['CleanRoomAssetVolumeLocalDetailsArgs']]):
        pulumi.set(self, "volume_local_details", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("databricks:index/cleanRoomAsset:CleanRoomAsset")
class CleanRoomAsset(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asset_type: Optional[pulumi.Input[_builtins.str]] = None,
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 foreign_table: Optional[pulumi.Input[Union['CleanRoomAssetForeignTableArgs', 'CleanRoomAssetForeignTableArgsDict']]] = None,
                 foreign_table_local_details: Optional[pulumi.Input[Union['CleanRoomAssetForeignTableLocalDetailsArgs', 'CleanRoomAssetForeignTableLocalDetailsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notebook: Optional[pulumi.Input[Union['CleanRoomAssetNotebookArgs', 'CleanRoomAssetNotebookArgsDict']]] = None,
                 table: Optional[pulumi.Input[Union['CleanRoomAssetTableArgs', 'CleanRoomAssetTableArgsDict']]] = None,
                 table_local_details: Optional[pulumi.Input[Union['CleanRoomAssetTableLocalDetailsArgs', 'CleanRoomAssetTableLocalDetailsArgsDict']]] = None,
                 view: Optional[pulumi.Input[Union['CleanRoomAssetViewArgs', 'CleanRoomAssetViewArgsDict']]] = None,
                 view_local_details: Optional[pulumi.Input[Union['CleanRoomAssetViewLocalDetailsArgs', 'CleanRoomAssetViewLocalDetailsArgsDict']]] = None,
                 volume_local_details: Optional[pulumi.Input[Union['CleanRoomAssetVolumeLocalDetailsArgs', 'CleanRoomAssetVolumeLocalDetailsArgsDict']]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Clean room assets are data and code objects -- tables, volumes, and notebooks that are shared with the clean room.

        ## Example Usage

        # Example: Clean Room Asset Resource

        ### Example for sharing a table
        This is an example for sharing an asset (table) in a clean room:
        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.index.CleanRoomsAsset("this",
            clean_room_name=existing_clean_room,
            name=creator.default.myasset,
            asset_type=TABLE,
            table_local_details={
                localName: some_creator.default.myasset,
            })
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "clean_room_name,name,asset_type"

          to = databricks_clean_room_asset.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/cleanRoomAsset:CleanRoomAsset databricks_clean_room_asset "clean_room_name,name,asset_type"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] asset_type: The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this asset belongs to.
               This field is required for create operations and populated by the server for responses
        :param pulumi.Input[Union['CleanRoomAssetForeignTableArgs', 'CleanRoomAssetForeignTableArgsDict']] foreign_table: Foreign table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input[Union['CleanRoomAssetForeignTableLocalDetailsArgs', 'CleanRoomAssetForeignTableLocalDetailsArgsDict']] foreign_table_local_details: Local details for a foreign that are only available to its owner.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input[_builtins.str] name: A fully qualified name that uniquely identifies the asset within the clean room.
               This is also the name displayed in the clean room UI.
               
               For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*
               
               For notebooks, the name is the notebook file name.
               For jar analyses, the name is the jar analysis name
        :param pulumi.Input[Union['CleanRoomAssetNotebookArgs', 'CleanRoomAssetNotebookArgsDict']] notebook: Notebook details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **NOTEBOOK_FILE**
        :param pulumi.Input[Union['CleanRoomAssetTableArgs', 'CleanRoomAssetTableArgsDict']] table: Table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input[Union['CleanRoomAssetTableLocalDetailsArgs', 'CleanRoomAssetTableLocalDetailsArgsDict']] table_local_details: Local details for a table that are only available to its owner.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input[Union['CleanRoomAssetViewArgs', 'CleanRoomAssetViewArgsDict']] view: View details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input[Union['CleanRoomAssetViewLocalDetailsArgs', 'CleanRoomAssetViewLocalDetailsArgsDict']] view_local_details: Local details for a view that are only available to its owner.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input[Union['CleanRoomAssetVolumeLocalDetailsArgs', 'CleanRoomAssetVolumeLocalDetailsArgsDict']] volume_local_details: Local details for a volume that are only available to its owner.
               Present if and only if **asset_type** is **VOLUME**
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CleanRoomAssetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Clean room assets are data and code objects -- tables, volumes, and notebooks that are shared with the clean room.

        ## Example Usage

        # Example: Clean Room Asset Resource

        ### Example for sharing a table
        This is an example for sharing an asset (table) in a clean room:
        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.index.CleanRoomsAsset("this",
            clean_room_name=existing_clean_room,
            name=creator.default.myasset,
            asset_type=TABLE,
            table_local_details={
                localName: some_creator.default.myasset,
            })
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "clean_room_name,name,asset_type"

          to = databricks_clean_room_asset.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/cleanRoomAsset:CleanRoomAsset databricks_clean_room_asset "clean_room_name,name,asset_type"
        ```

        :param str resource_name: The name of the resource.
        :param CleanRoomAssetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CleanRoomAssetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asset_type: Optional[pulumi.Input[_builtins.str]] = None,
                 clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
                 foreign_table: Optional[pulumi.Input[Union['CleanRoomAssetForeignTableArgs', 'CleanRoomAssetForeignTableArgsDict']]] = None,
                 foreign_table_local_details: Optional[pulumi.Input[Union['CleanRoomAssetForeignTableLocalDetailsArgs', 'CleanRoomAssetForeignTableLocalDetailsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notebook: Optional[pulumi.Input[Union['CleanRoomAssetNotebookArgs', 'CleanRoomAssetNotebookArgsDict']]] = None,
                 table: Optional[pulumi.Input[Union['CleanRoomAssetTableArgs', 'CleanRoomAssetTableArgsDict']]] = None,
                 table_local_details: Optional[pulumi.Input[Union['CleanRoomAssetTableLocalDetailsArgs', 'CleanRoomAssetTableLocalDetailsArgsDict']]] = None,
                 view: Optional[pulumi.Input[Union['CleanRoomAssetViewArgs', 'CleanRoomAssetViewArgsDict']]] = None,
                 view_local_details: Optional[pulumi.Input[Union['CleanRoomAssetViewLocalDetailsArgs', 'CleanRoomAssetViewLocalDetailsArgsDict']]] = None,
                 volume_local_details: Optional[pulumi.Input[Union['CleanRoomAssetVolumeLocalDetailsArgs', 'CleanRoomAssetVolumeLocalDetailsArgsDict']]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CleanRoomAssetArgs.__new__(CleanRoomAssetArgs)

            if asset_type is None and not opts.urn:
                raise TypeError("Missing required property 'asset_type'")
            __props__.__dict__["asset_type"] = asset_type
            __props__.__dict__["clean_room_name"] = clean_room_name
            __props__.__dict__["foreign_table"] = foreign_table
            __props__.__dict__["foreign_table_local_details"] = foreign_table_local_details
            __props__.__dict__["name"] = name
            __props__.__dict__["notebook"] = notebook
            __props__.__dict__["table"] = table
            __props__.__dict__["table_local_details"] = table_local_details
            __props__.__dict__["view"] = view
            __props__.__dict__["view_local_details"] = view_local_details
            __props__.__dict__["volume_local_details"] = volume_local_details
            __props__.__dict__["workspace_id"] = workspace_id
            __props__.__dict__["added_at"] = None
            __props__.__dict__["owner_collaborator_alias"] = None
            __props__.__dict__["status"] = None
        super(CleanRoomAsset, __self__).__init__(
            'databricks:index/cleanRoomAsset:CleanRoomAsset',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            added_at: Optional[pulumi.Input[_builtins.int]] = None,
            asset_type: Optional[pulumi.Input[_builtins.str]] = None,
            clean_room_name: Optional[pulumi.Input[_builtins.str]] = None,
            foreign_table: Optional[pulumi.Input[Union['CleanRoomAssetForeignTableArgs', 'CleanRoomAssetForeignTableArgsDict']]] = None,
            foreign_table_local_details: Optional[pulumi.Input[Union['CleanRoomAssetForeignTableLocalDetailsArgs', 'CleanRoomAssetForeignTableLocalDetailsArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notebook: Optional[pulumi.Input[Union['CleanRoomAssetNotebookArgs', 'CleanRoomAssetNotebookArgsDict']]] = None,
            owner_collaborator_alias: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            table: Optional[pulumi.Input[Union['CleanRoomAssetTableArgs', 'CleanRoomAssetTableArgsDict']]] = None,
            table_local_details: Optional[pulumi.Input[Union['CleanRoomAssetTableLocalDetailsArgs', 'CleanRoomAssetTableLocalDetailsArgsDict']]] = None,
            view: Optional[pulumi.Input[Union['CleanRoomAssetViewArgs', 'CleanRoomAssetViewArgsDict']]] = None,
            view_local_details: Optional[pulumi.Input[Union['CleanRoomAssetViewLocalDetailsArgs', 'CleanRoomAssetViewLocalDetailsArgsDict']]] = None,
            volume_local_details: Optional[pulumi.Input[Union['CleanRoomAssetVolumeLocalDetailsArgs', 'CleanRoomAssetVolumeLocalDetailsArgsDict']]] = None,
            workspace_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'CleanRoomAsset':
        """
        Get an existing CleanRoomAsset resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] added_at: (integer) - When the asset is added to the clean room, in epoch milliseconds
        :param pulumi.Input[_builtins.str] asset_type: The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        :param pulumi.Input[_builtins.str] clean_room_name: The name of the clean room this asset belongs to.
               This field is required for create operations and populated by the server for responses
        :param pulumi.Input[Union['CleanRoomAssetForeignTableArgs', 'CleanRoomAssetForeignTableArgsDict']] foreign_table: Foreign table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input[Union['CleanRoomAssetForeignTableLocalDetailsArgs', 'CleanRoomAssetForeignTableLocalDetailsArgsDict']] foreign_table_local_details: Local details for a foreign that are only available to its owner.
               Present if and only if **asset_type** is **FOREIGN_TABLE**
        :param pulumi.Input[_builtins.str] name: A fully qualified name that uniquely identifies the asset within the clean room.
               This is also the name displayed in the clean room UI.
               
               For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*
               
               For notebooks, the name is the notebook file name.
               For jar analyses, the name is the jar analysis name
        :param pulumi.Input[Union['CleanRoomAssetNotebookArgs', 'CleanRoomAssetNotebookArgsDict']] notebook: Notebook details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **NOTEBOOK_FILE**
        :param pulumi.Input[_builtins.str] owner_collaborator_alias: (string) - The alias of the collaborator who owns this asset
        :param pulumi.Input[_builtins.str] status: (string) - Status of the asset. Possible values are: `ACTIVE`, `PENDING`, `PERMISSION_DENIED`
        :param pulumi.Input[Union['CleanRoomAssetTableArgs', 'CleanRoomAssetTableArgsDict']] table: Table details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input[Union['CleanRoomAssetTableLocalDetailsArgs', 'CleanRoomAssetTableLocalDetailsArgsDict']] table_local_details: Local details for a table that are only available to its owner.
               Present if and only if **asset_type** is **TABLE**
        :param pulumi.Input[Union['CleanRoomAssetViewArgs', 'CleanRoomAssetViewArgsDict']] view: View details available to all collaborators of the clean room.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input[Union['CleanRoomAssetViewLocalDetailsArgs', 'CleanRoomAssetViewLocalDetailsArgsDict']] view_local_details: Local details for a view that are only available to its owner.
               Present if and only if **asset_type** is **VIEW**
        :param pulumi.Input[Union['CleanRoomAssetVolumeLocalDetailsArgs', 'CleanRoomAssetVolumeLocalDetailsArgsDict']] volume_local_details: Local details for a volume that are only available to its owner.
               Present if and only if **asset_type** is **VOLUME**
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CleanRoomAssetState.__new__(_CleanRoomAssetState)

        __props__.__dict__["added_at"] = added_at
        __props__.__dict__["asset_type"] = asset_type
        __props__.__dict__["clean_room_name"] = clean_room_name
        __props__.__dict__["foreign_table"] = foreign_table
        __props__.__dict__["foreign_table_local_details"] = foreign_table_local_details
        __props__.__dict__["name"] = name
        __props__.__dict__["notebook"] = notebook
        __props__.__dict__["owner_collaborator_alias"] = owner_collaborator_alias
        __props__.__dict__["status"] = status
        __props__.__dict__["table"] = table
        __props__.__dict__["table_local_details"] = table_local_details
        __props__.__dict__["view"] = view
        __props__.__dict__["view_local_details"] = view_local_details
        __props__.__dict__["volume_local_details"] = volume_local_details
        __props__.__dict__["workspace_id"] = workspace_id
        return CleanRoomAsset(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="addedAt")
    def added_at(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - When the asset is added to the clean room, in epoch milliseconds
        """
        return pulumi.get(self, "added_at")

    @_builtins.property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the asset. Possible values are: `FOREIGN_TABLE`, `NOTEBOOK_FILE`, `TABLE`, `VIEW`, `VOLUME`
        """
        return pulumi.get(self, "asset_type")

    @_builtins.property
    @pulumi.getter(name="cleanRoomName")
    def clean_room_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the clean room this asset belongs to.
        This field is required for create operations and populated by the server for responses
        """
        return pulumi.get(self, "clean_room_name")

    @_builtins.property
    @pulumi.getter(name="foreignTable")
    def foreign_table(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetForeignTable']]:
        """
        Foreign table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table")

    @_builtins.property
    @pulumi.getter(name="foreignTableLocalDetails")
    def foreign_table_local_details(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetForeignTableLocalDetails']]:
        """
        Local details for a foreign that are only available to its owner.
        Present if and only if **asset_type** is **FOREIGN_TABLE**
        """
        return pulumi.get(self, "foreign_table_local_details")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A fully qualified name that uniquely identifies the asset within the clean room.
        This is also the name displayed in the clean room UI.

        For UC securable assets (tables, volumes, etc.), the format is *shared_catalog*.*shared_schema*.*asset_name*

        For notebooks, the name is the notebook file name.
        For jar analyses, the name is the jar analysis name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def notebook(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetNotebook']]:
        """
        Notebook details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **NOTEBOOK_FILE**
        """
        return pulumi.get(self, "notebook")

    @_builtins.property
    @pulumi.getter(name="ownerCollaboratorAlias")
    def owner_collaborator_alias(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The alias of the collaborator who owns this asset
        """
        return pulumi.get(self, "owner_collaborator_alias")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Status of the asset. Possible values are: `ACTIVE`, `PENDING`, `PERMISSION_DENIED`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def table(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetTable']]:
        """
        Table details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table")

    @_builtins.property
    @pulumi.getter(name="tableLocalDetails")
    def table_local_details(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetTableLocalDetails']]:
        """
        Local details for a table that are only available to its owner.
        Present if and only if **asset_type** is **TABLE**
        """
        return pulumi.get(self, "table_local_details")

    @_builtins.property
    @pulumi.getter
    def view(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetView']]:
        """
        View details available to all collaborators of the clean room.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view")

    @_builtins.property
    @pulumi.getter(name="viewLocalDetails")
    def view_local_details(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetViewLocalDetails']]:
        """
        Local details for a view that are only available to its owner.
        Present if and only if **asset_type** is **VIEW**
        """
        return pulumi.get(self, "view_local_details")

    @_builtins.property
    @pulumi.getter(name="volumeLocalDetails")
    def volume_local_details(self) -> pulumi.Output[Optional['outputs.CleanRoomAssetVolumeLocalDetails']]:
        """
        Local details for a volume that are only available to its owner.
        Present if and only if **asset_type** is **VOLUME**
        """
        return pulumi.get(self, "volume_local_details")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TagPolicyArgs', 'TagPolicy']

@pulumi.input_type
class TagPolicyArgs:
    def __init__(__self__, *,
                 tag_key: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a TagPolicy resource.
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        pulumi.set(__self__, "tag_key", tag_key)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if values is not None:
            pulumi.set(__self__, "values", values)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "tag_key")

    @tag_key.setter
    def tag_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "tag_key", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]):
        pulumi.set(self, "values", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.input_type
class _TagPolicyState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering TagPolicy resources.
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if tag_key is not None:
            pulumi.set(__self__, "tag_key", tag_key)
        if values is not None:
            pulumi.set(__self__, "values", values)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "tag_key")

    @tag_key.setter
    def tag_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag_key", value)

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TagPolicyValueArgs']]]]):
        pulumi.set(self, "values", value)

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("databricks:index/tagPolicy:TagPolicy")
class TagPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TagPolicyValueArgs', 'TagPolicyValueArgsDict']]]]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Define tag policies to manage governed tags in your account.

        > **Note** This resource can only be used with an account-level provider!

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "tag_key"

          to = databricks_tag_policy.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/tagPolicy:TagPolicy databricks_tag_policy "tag_key"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TagPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Define tag policies to manage governed tags in your account.

        > **Note** This resource can only be used with an account-level provider!

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "tag_key"

          to = databricks_tag_policy.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/tagPolicy:TagPolicy databricks_tag_policy "tag_key"
        ```

        :param str resource_name: The name of the resource.
        :param TagPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TagPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TagPolicyValueArgs', 'TagPolicyValueArgsDict']]]]] = None,
                 workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TagPolicyArgs.__new__(TagPolicyArgs)

            __props__.__dict__["description"] = description
            if tag_key is None and not opts.urn:
                raise TypeError("Missing required property 'tag_key'")
            __props__.__dict__["tag_key"] = tag_key
            __props__.__dict__["values"] = values
            __props__.__dict__["workspace_id"] = workspace_id
        super(TagPolicy, __self__).__init__(
            'databricks:index/tagPolicy:TagPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            tag_key: Optional[pulumi.Input[_builtins.str]] = None,
            values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TagPolicyValueArgs', 'TagPolicyValueArgsDict']]]]] = None,
            workspace_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'TagPolicy':
        """
        Get an existing TagPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] workspace_id: Workspace ID of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TagPolicyState.__new__(_TagPolicyState)

        __props__.__dict__["description"] = description
        __props__.__dict__["tag_key"] = tag_key
        __props__.__dict__["values"] = values
        __props__.__dict__["workspace_id"] = workspace_id
        return TagPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "tag_key")

    @_builtins.property
    @pulumi.getter
    def values(self) -> pulumi.Output[Optional[Sequence['outputs.TagPolicyValue']]]:
        return pulumi.get(self, "values")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Workspace ID of the resource
        """
        return pulumi.get(self, "workspace_id")

